==> gratia_0.9.0.tar.gz: gratia/tests/testthat/_snaps/add-functions.md <==
# add_fitted_samples works

    Code
      print(fs)
    Output
      # A tibble: 600 x 13
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .draw
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <int>
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     1
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     2
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     1
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     2
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     1
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     2
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     1
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     2
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     1
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     2
      # i 590 more rows
      # i 1 more variable: .fitted <dbl>

# add_predicted_samples works

    Code
      print(ps)
    Output
      # A tibble: 600 x 13
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .draw
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <int>
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     1
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     2
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     1
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     2
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     1
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     2
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     1
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     2
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     1
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     2
      # i 590 more rows
      # i 1 more variable: .response <dbl>

# add_posterior_samples works

    Code
      print(ps)
    Output
      # A tibble: 600 x 13
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .draw
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <int>
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     1
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     2
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     1
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     2
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     1
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     2
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     1
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     2
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     1
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     2
      # i 590 more rows
      # i 1 more variable: .response <dbl>

# add_smooth_samples works

    Code
      print(ss)
    Output
      # A tibble: 2,400 x 15
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .smooth
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <chr>  
       1  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x0)  
       2  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x0)  
       3  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x1)  
       4  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x1)  
       5  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x2)  
       6  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x2)  
       7  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x3)  
       8  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x3)  
       9  13.5 0.252 0.0412 0.153 0.541  9.33  1.43  1.09  6.82     0     2 s(x0)  
      10  13.5 0.252 0.0412 0.153 0.541  9.33  1.43  1.09  6.82     0     2 s(x0)  
      # i 2,390 more rows
      # i 3 more variables: .term <chr>, .draw <int>, .value <dbl>

# add_smooth_samples works for selected smooth

    Code
      print(ss)
    Output
      # A tibble: 600 x 15
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .smooth
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <chr>  
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1 s(x2)  
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1 s(x2)  
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2 s(x2)  
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2 s(x2)  
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3 s(x2)  
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3 s(x2)  
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4 s(x2)  
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4 s(x2)  
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5 s(x2)  
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5 s(x2)  
      # i 590 more rows
      # i 3 more variables: .term <chr>, .draw <int>, .value <dbl>

==> gratia_0.11.1.tar.gz: gratia/tests/testthat/_snaps/add-functions.md <==
# add_fitted_samples works

    Code
      print(fs)
    Output
      # A tibble: 600 x 14
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .draw
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <int>
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     1
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     2
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     1
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     2
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     1
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     2
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     1
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     2
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     1
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     2
      # i 590 more rows
      # i 2 more variables: .parameter <chr>, .fitted <dbl>

# add_predicted_samples works

    Code
      print(ps)
    Output
      # A tibble: 600 x 13
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .draw
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <int>
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     1
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     2
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     1
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     2
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     1
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     2
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     1
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     2
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     1
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     2
      # i 590 more rows
      # i 1 more variable: .response <dbl>

# add_posterior_samples works

    Code
      print(ps)
    Output
      # A tibble: 600 x 13
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .draw
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <int>
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     1
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1     2
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     1
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2     2
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     1
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3     2
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     1
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4     2
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     1
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5     2
      # i 590 more rows
      # i 1 more variable: .response <dbl>

# add_smooth_samples works

    Code
      print(ss)
    Output
      # A tibble: 2,400 x 15
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .smooth
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <chr>  
       1  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x0)  
       2  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x0)  
       3  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x1)  
       4  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x1)  
       5  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x2)  
       6  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x2)  
       7  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x3)  
       8  10.1 0.786 0.709  0.119 0.975 10.1   1.25  4.13  4.73     0     1 s(x3)  
       9  13.5 0.252 0.0412 0.153 0.541  9.33  1.43  1.09  6.82     0     2 s(x0)  
      10  13.5 0.252 0.0412 0.153 0.541  9.33  1.43  1.09  6.82     0     2 s(x0)  
      # i 2,390 more rows
      # i 3 more variables: .term <chr>, .draw <int>, .value <dbl>

# add_smooth_samples works for selected smooth

    Code
      print(ss)
    Output
      # A tibble: 600 x 15
             y    x0     x1    x2    x3     f    f0    f1    f2    f3  .row .smooth
         <dbl> <dbl>  <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <int> <chr>  
       1 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1 s(x2)  
       2 10.1  0.786 0.709  0.119 0.975 10.1  1.25   4.13  4.73     0     1 s(x2)  
       3 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2 s(x2)  
       4 13.5  0.252 0.0412 0.153 0.541  9.33 1.43   1.09  6.82     0     2 s(x2)  
       5  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3 s(x2)  
       6  6.61 0.699 0.245  0.110 0.975  7.38 1.62   1.63  4.13     0     3 s(x2)  
       7  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4 s(x2)  
       8  7.09 0.184 0.160  0.681 0.861  5.58 1.10   1.38  3.11     0     4 s(x2)  
       9  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5 s(x2)  
      10  7.88 0.960 0.0939 0.676 0.252  4.62 0.253  1.21  3.16     0     5 s(x2)  
      # i 590 more rows
      # i 3 more variables: .term <chr>, .draw <int>, .value <dbl>
